const fetch = require('isomorphic-fetch');

class ApiResource {

  static post(config, resourcePath, payload = {}) {
    this._config = config;

    if (!this._config.API_KEY || this._config.API_KEY === '') {
      throw new Error('API_KEY is not set. Please set your api key: LiveQA.API_KEY = \'xxxx\'');
    }

    return this.request('post', resourcePath, payload);
  }

  static request(method, resourcePath, payload = {}) {
    const url = `${this._config.HOST}/api/${this._config.API_VERSION}/${resourcePath}`;

    const requestOptions = {
      method: 'POST',
      body: JSON.stringify(payload),
      mode: 'cors',
      headers: new Headers({
        'Access-Control-Allow-Origin': '*',
        'Content-Type': 'application/json',
        Accept: 'application/json',
        'X-Request-Key': this._config.API_KEY,
      })
    };

    this._send(url, requestOptions);
  }

  // private

  static set _config(value) {
    this.configuration = value;
  }

  static get _config() {
    return this.configuration;
  }

  static _send(url, options) {
    return fetch(url, options)
      .then((response) => {
        switch (response.status) {
          case 400:
            throw new Error('Bad response from server');
          case 401:
            throw new Error('Unauthorized, please check your api key');
          case 404:
            throw new Error('Requested Resource not found');
          case 408:
            throw new Error('Server timeout, verify status of the server');
          case 444:
            throw new Error('Server Error, please check with LiveQA');
          case 449:
            throw new Error('Server Error, please check with LiveQA');
          case 501:
            throw new Error('Server Error, please check with LiveQA');
          default:
            return response;
        }
      })
      .then(response => response)
      .catch(() => { throw new Error('Server Error, please check with LiveQA'); });
  }
}

module.exports = ApiResource;
