import Chai, { expect } from 'chai';
import sinon from 'sinon';
import sinonChai from 'sinon-chai';
import path from 'path';

import Config from '../sources/config';
import ApiResource from '../sources/api_resource';

Chai.use(sinonChai);

describe('ApiResource', () => {
  let apiResource;

  beforeEach(() => {
    sinon.stub(ApiResource, '_send')

    Config.API_KEY = 'xxx'
    Config.SNIPPET_VERSION = '1.0.0'
    ApiResource._config = Config
  })

  afterEach(() => {
    ApiResource._send.restore()
  })

  describe('#post', () => {
    it("whithout an api key raise an error", () => {
      Config.API_KEY = undefined

      expect(() => { ApiResource.post(ApiResource._config, 'test') }).to.throw('API_KEY is not set. Please set your api key: LiveQA.API_KEY = \'xxxx\'');
    })

    it("call the server with the correct attribute", () => {
      ApiResource._send.restore()

      let spy = sinon.spy(ApiResource, '_send')

      ApiResource.post(ApiResource._config, 'test')

      expect(spy).to.have.been.called
    })
  })

})
