import Chai, { expect } from 'chai';
import sinon from 'sinon';
import sinonChai from 'sinon-chai';
import path from 'path';

import Config from '../sources/config';
import ApiResource from '../sources/api_resource';
import Event from '../sources/event';

Chai.use(sinonChai);

describe('Event', () => {
  let event;

  beforeEach(() => {
    sinon.stub(ApiResource, '_send')

    Config.API_KEY = 'xxx'
    Config.SNIPPET_VERSION = '1.0.0'
    Event._config = Config
  })

  afterEach(() => {
    ApiResource._send.restore()
  })

  describe('#_context', () => {
    it('name', () => {
      expect(Event._context).to.have.deep.property('library.name', Config.LIBRARY_NAME)
    })

    it('language', () => {
      expect(Event._context).to.have.deep.property('library.language', Config.LANGUAGE)
    })

    it('version', () => {
      expect(Event._context).to.have.deep.property('library.version', Config.VERSION)
    })

    it('snippet_version', () => {
      expect(Event._context).to.have.deep.property('library.snippet_version', Config.SNIPPET_VERSION)
    })
  })

  describe('#_buildPayload', () => {
    let payload;

    beforeEach(() => {
      let properties = { test: 'test_property' }

      payload = Event._buildPayload('test event', properties)
    })

    it('name', () => {
      expect(payload['name']).to.eq('test event')
      expect(payload).to.have.property('name', 'test event')
    })

    it('message_id', () => {
      expect(payload['message_id']).to.exist
    })

    it('properties', () => {
      expect(payload).to.have.deep.property('properties.test', 'test_property')
    })

    it('context', () => {
      expect(payload['context']).to.exist
    })

    it('timestamp', () => {
      expect(payload['timestamp']).to.exist
    })

  })

  describe('#_timestamp', () => {
    it('number', () => {
      expect(Event._timestamp).to.be.a('number')
    })
  })

  describe('#create', () => {
    it('call api resource', () => {
      let spy = sinon.spy(ApiResource, 'post');

      Event.create(Event._config, 'test')

      expect(spy).to.have.been.calledOnce.calledWith(Event._config, 'events')
    })
  })

})
